@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of mediastreamer2.
+ * This file is part of mediastreamer2 
+ * (see https://gitlab.linphone.org/BC/public/mediastreamer2).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef mscommon_h
@@ -47,7 +48,6 @@
 #define MS2_DEPRECATED __attribute__ ((deprecated))
 #endif
 #endif
-#define MS_UNUSED(x) ((void)(x))
 
 #define ms_malloc	ortp_malloc
 #define ms_malloc0	ortp_malloc0
@@ -56,7 +56,7 @@
 #define ms_new0		ortp_new0
 #define ms_free		ortp_free
 #define ms_strdup	ortp_strdup
-#define ms_strndup	ortp_strndup
+#define ms_strndup	bctbx_strndup
 #define ms_strdup_printf	ortp_strdup_printf
 #define ms_strcat_printf	ortp_strcat_printf
 
@@ -150,7 +150,7 @@ static MS2_INLINE void ms_debug(const char *fmt,...)
 typedef ortpTimeSpec MSTimeSpec;
 
 #define ms_get_cur_time ortp_get_cur_time
-#define ms_get_cur_time_ms ortp_get_cur_time_ms
+#define ms_get_cur_time_ms bctbx_get_cur_time_ms
 
 typedef bctbx_compare_func MSCompareFunc;
 typedef void (*MSIterateFunc)(void *a);
@@ -261,7 +261,7 @@ MS2_PUBLIC MS2_DEPRECATED void ms_list_for_each(const MSList *list, MSIterateFun
  * @deprecated Use bctbx_list_for_each2() instead
 **/
 MS2_PUBLIC MS2_DEPRECATED void ms_list_for_each2(const MSList *list, MSIterate2Func iterate_func, void *user_data);
-	
+
 MS2_PUBLIC MS2_DEPRECATED void ms_list_for_each3(const MSList *list, MSIterate3Func iterate_func, void *user_data, void *factory);
 
 /** Finds and remove given element in list.
@@ -593,4 +593,3 @@ MS2_PUBLIC char *ms_load_path_content(const char *path, size_t *nbytes);
 #include "mediastreamer2/msjava.h"
 #endif
 #endif
-
